# Analysing an Image

## Choosing the analysis parameters

## Interacting with your results

## Saving your results

## Batch processing
Once you're happy with your analysis settings, you can choose to batch analyse multiple files and folders at once. If you are interested in doing this you can refer to the [batch tools guide](../usage/batch_tools_example.md). You can access the batch tools by running `micromorph-batch` or clicking on the "Batch Tools" button in the napari plugin, which opens the same GUI.